from setuptools import find_packages, setup

setup(
    name="pcap_blur",
    version="0.1.0",
    description="Pcap Blur is a command line tool that anonymizes network traffic.",
    url="https://github.com/rafaelsilva81/pcap-blur",
    author="Rafael Galdino da Silva",
    author_email="rafaelgaldinosilva81@gmail.com",
    license="MIT",
    packages=find_packages(),
    entry_points={
        "console_scripts": [
            "pcap-blur=pcap_blur.main:main",
            "pcap_blur=pcap_blur.main:main",
            "pcapblur=pcap_blur.main:main",
        ],
    },
    install_requires=[
        "altgraph==0.17.4",
        "annotated-types==0.6.0",
        "anyio==4.3.0",
        "appdirs==1.4.4",
        "certifi==2024.2.2",
        "cffi==1.16.0",
        "click==8.1.7",
        "colorama==0.4.6",
        "cryptography==42.0.7",
        "dnspython==2.6.1",
        "email_validator==2.1.1",
        "fastapi==0.111.0",
        "fastapi-cli==0.0.3",
        "h11==0.14.0",
        "httpcore==1.0.5",
        "httptools==0.6.1",
        "httpx==0.27.0",
        "idna==3.7",
        "Jinja2==3.1.4",
        "line_profiler==4.1.3",
        "lxml==5.2.1",
        "markdown-it-py==3.0.0",
        "MarkupSafe==2.1.5",
        "mdurl==0.1.2",
        "memory-profiler==0.61.0",
        "orjson==3.10.3",
        "packaging==24.0",
        "pefile==2023.2.7",
        "picologging==0.9.3",
        "psutil==5.9.8",
        "py-spy==0.3.14",
        "pycparser==2.22",
        "pycryptodome==3.20.0",
        "pydantic==2.7.1",
        "pydantic_core==2.18.2",
        "Pygments==2.18.0",
        "pyinstaller==6.5.0",
        "pyinstaller-hooks-contrib==2024.3",
        "python-dotenv==1.0.1",
        "python-multipart==0.0.9",
        "pytz==2024.1",
        "pywin32-ctypes==0.2.2",
        "PyYAML==6.0.1",
        "rich==13.7.1",
        "scapy==2.5.0",
        "setuptools==69.2.0",
        "shellingham==1.5.4",
        "sniffio==1.3.1",
        "starlette==0.37.2",
        "termcolor==2.4.0",
        "typer==0.12.3",
        "typing_extensions==4.11.0",
        "tzdata==2024.1",
        "tzlocal==5.2",
        "ujson==5.9.0",
        "uvicorn==0.29.0",
        "watchfiles==0.21.0",
        "websockets==12.0",
        "yacryptopan==1.0.1",
    ],
    python_requires=">=3.10",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Topic :: Security",
        "Topic :: Security :: Cryptography",
        "Topic :: System :: Networking",
        "Topic :: Utilities",
    ],
)
